==> atombrew-0.0.6-py3-none-any.whl: atombrew/analysis/RDF/_rdf_np.py <==
import numpy as np
from tqdm import trange
from ._rdfinterface import RDFInterface


class ByNumpy(RDFInterface):
    def __init__(self, a, b, box=None, r_max: float = None, resolution: int = 1000, dtype: str = ...):
        self.a = np.array(a, dtype=float)
        self.b = np.array(b, dtype=float)
        self.box = self.__check_box_dim(box=box)
        super().__init__(box, r_max, resolution, dtype)

    @property
    def n_a(self):
        if not hasattr(self, "_n_a"):
            self._n_a = self.a.shape[1]
        return self._n_a

    @property
    def n_b(self):
        if not hasattr(self, "_n_b"):
            self._n_b = self.a.shape[1]
        return self._n_b

    def run(self, start=0, stop=None, step=1):
        stop = len(self.a) if stop is None else stop
        for frame in trange(start, stop, step, unit="frame"):
            unit_a = self.a[frame, ...]
            unit_b = self.b[frame, ...]
            unit_box = self.box[frame, ...]
            self._update_hist(unit_a, unit_b, unit_box)
        return self

    def __check_box_dim(self, box):
        assert box is not None, "Please Input Box"
        box = np.array(box, dtype=float)
        assert np.prod(box), f"Box shape should be (nframe, 3). not {box.shape}"
        nframe_box = len(box)
        nframe_a = len(self.a)
        nframe_b = len(self.b)
        assert nframe_a == nframe_b, "a and b frame must be same."
        if nframe_box == nframe_a:
            return box
        elif box.ndim == 1:
            return np.tile(box, [nframe_a, 1])
        else:
            raise ValueError(f"Box shape is incorrect, (nframe Box : A : B = {nframe_box} : {nframe_a} : {nframe_b})")

==> atombrew-0.0.9-py3-none-any.whl: atombrew/analysis/RDF/_rdf_np.py <==
import numpy as np
from tqdm import trange
from ._rdfinterface import RDFInterface


class ByNumpy(RDFInterface):
    def __init__(self, a, b, box=None, r_max: float = None, resolution: int = 1000, dtype: str = ...):
        assert len(a) == len(b), f"Not equal frame of a({len(a)}) and b({len(b)})"
        self.a = np.array(a, dtype=float)
        self.b = np.array(b, dtype=float)
        self.box = self.__check_box(box=box)
        super().__init__(box, r_max, resolution, dtype)

    @property
    def n_a(self):
        if not hasattr(self, "_n_a"):
            self._n_a = self.a.shape[1]
        return self._n_a

    @property
    def n_b(self):
        if not hasattr(self, "_n_b"):
            self._n_b = self.b.shape[1]
        return self._n_b

    def run(self, start=0, stop=None, step=1):
        stop = len(self.a) if stop is None else stop
        for frame in trange(start, stop, step, unit="frame"):
            unit_a = self.a[frame, ...]
            unit_b = self.b[frame, ...]
            unit_box = self.box[frame, ...]
            self._update_hist(unit_a, unit_b, unit_box)
        return self

    def __check_box(self, box):
        assert box is not None, "Please Input Box"
        box = np.array(box, dtype=float)
        if box.ndim == 3 and box.shape[1:] == (3, 3):
            return np.array([np.diag(b) for b in box])
        elif box.ndim == 2:
            return box
        elif box.ndim == 1 and len(box) == 3:
            return np.tile(box, [len(self.a), 1])
        else:
            raise ValueError(f"Box should be in shape, (nframe, 3, 3), (nframe, 3), (3,)")
